@@ -416,9 +416,8 @@ class HiveRepo:
         return self.db.naming().db_table_path(table_name if table_name else self.table_name)
 
     def delta_table_location(self, table_name=None):
-        if (self.db.config.is_running_in_test and
-                not self.db.config.db.db_path_override_for_checkpoint):
-            raise repo_messages.checkpoint_override_must_be_supported_in_test()
+        if not self.db.naming().delta_table_naming_correctly_configured():
+            raise repo_messages.delta_location_configured_incorrectly()
         return self.db.naming().delta_table_location(table_name if table_name else self.table_name)
 
     #
